EVP_ENCODE_CTX

Type Alias EVP_ENCODE_CTX 

pub type EVP_ENCODE_CTX = evp_encode_ctx_st;
@typedef EVP_ENCODE_CTX @copydoc evp_encode_ctx_st @see evp_encode_ctx_st

Aliased Type

#[repr(C)]
pub struct EVP_ENCODE_CTX { pub data_used: u32, pub data: [u8; 48], pub eof_seen: i8, pub error_encountered: i8, }

Fields

data_used: u32

@brief Number of valid bytes

@details When encoding, data will be filled and encoded as a lump. When decoding, only the first four bytes of data will be used.

data: [u8; 48]

@brief Encoded or decoded data.

eof_seen: i8

@brief Indicates that the end of the base64 data has been seen.

@details Only used when decoding. Only whitespace can follow.

error_encountered: i8

@brief indicates that invalid base64 data was found.

@details This will gitcause all future calls to fail.